function out = wc2mat(in)

% wc2mat arranges output from fx wc_rand in matrix form
%
% L = 10;
% wc2mat(wc_rand(L,1,1,eye(2))/L)
% [zpol,zpoldeg] = cart2polc(wc2mat(wc_rand(L,1,1,eye(3))/L))

% (c) Copyright 2021-2022
% Allan Aasbjerg Nielsen, PhD, MSc
% alan@dtu.dk, people.compute.dtu.dk/alan
% 28 April 2021
% 3 Jan 2022 /reflection symmetry added

[nr,nc,nel] = size(in);
if and(nr==1,nc==1)
    if nel==9 % full/quad pol
        out = nan(3,3);
        out(1,1) = in(1);
        out(1,2) = complex(in(2),in(3));
        out(1,3) = complex(in(4),in(5));
        out(2,2) = in(6);
        out(2,3) = complex(in(7),in(8));
        out(3,3) = in(9);
        out(2,1) = conj(out(1,2));
        out(3,1) = conj(out(1,3));
        out(3,2) = conj(out(2,3));
    elseif nel==5 % reflection symmetry
        out = nan(3,3);
        out(1,1) = in(1);
        out(1,3) = complex(in(2),in(3));
        out(1,2) = 0;
        out(2,2) = in(4);
        out(2,3) = 0;
        out(3,3) = in(5);
        out(2,1) = conj(out(1,2));
        out(3,1) = conj(out(1,3));
        out(3,2) = conj(out(2,3));
    elseif nel==4 % dual pol
        out = nan(2,2);
        out(1,1) = in(1);
        out(1,2) = complex(in(2),in(3));
        out(2,2) = in(4);
        out(2,1) = conj(out(1,2));
    else
        warning('wc2mat: numel(in) must be 9, 5 or 4')
    end
else
    if nel==9
        out = nan(3,3,nr,nc);
        out(1,1,:,:) = in(:,:,1);
        out(1,2,:,:) = complex(in(:,:,2),in(:,:,3));
        out(1,3,:,:) = complex(in(:,:,4),in(:,:,5));
        out(2,2,:,:) = in(:,:,6);
        out(2,3,:,:) = complex(in(:,:,7),in(:,:,8));
        out(3,3,:,:) = in(:,:,9);
        out(2,1,:,:) = conj(out(1,2,:,:));
        out(3,1,:,:) = conj(out(1,3,:,:));
        out(3,2,:,:) = conj(out(2,3,:,:));
    elseif nel==5
        out = nan(3,3,nr,nc);
        out(1,1,:,:) = in(:,:,1);
        out(1,3,:,:) = complex(in(:,:,2),in(:,:,3));
        out(1,2,:,:) = 0;
        out(2,2,:,:) = in(:,:,4);
        out(2,3,:,:) = 0;
        out(3,3,:,:) = in(:,:,5);
        out(2,1,:,:) = conj(out(1,2,:,:));
        out(3,1,:,:) = conj(out(1,3,:,:));
        out(3,2,:,:) = conj(out(2,3,:,:));
    elseif nel==4
        out = nan(2,2,nr,nc);
        out(1,1,:,:) = in(:,:,1);
        out(1,2,:,:) = complex(in(:,:,2),in(:,:,3));
        out(2,2,:,:) = in(:,:,4);
        out(2,1,:,:) = conj(out(1,2,:,:));
    else
        warning('wc2mat: numel(in) must be 9, 5 or 4')
    end
end    
    